==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.js <==
var class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor =
[
    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1debd6d9332b92a9a2a40077ba908427", null ],
    [ "~SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#ac8c6da90e0c6ca347c97acdf9b3e8dff", null ],
    [ "visit", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a70902c2c92e63d1c234e5bb135230b66", null ],
    [ "visit", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a355e8d4526c10772c7d85798806f7f8a", null ],
    [ "renderObjects", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aaeb00285e4af4ab37e85b95801cb9af5", null ],
    [ "targetSceneMgr", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a5a00a39fe1147c5806c457a4a9feed88", null ],
    [ "transparentShadowCastersMode", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a9b568558ac92b819f6c141cfae20613f", null ],
    [ "autoLights", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#acf473d568a738bb42e81ef872fe600a2", null ],
    [ "manualLightList", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aa05f120964ef4bf3127dffa67c03480a", null ],
    [ "scissoring", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1f81a13b0b7ff39afa5e96e35728a40e", null ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.js <==
var class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor =
[
    [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1debd6d9332b92a9a2a40077ba908427", null ],
    [ "~SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#ac8c6da90e0c6ca347c97acdf9b3e8dff", null ],
    [ "visit", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a5aded8430792e58ecc85c0d5bf0a360a", null ],
    [ "visit", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a985f47ccacf0d434b3b80fd7fc06adce", null ],
    [ "renderObjects", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aaeb00285e4af4ab37e85b95801cb9af5", null ],
    [ "renderTransparents", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#af669ba0b9cb88fd2c6ceb4fa2aa816f5", null ],
    [ "targetSceneMgr", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a5a00a39fe1147c5806c457a4a9feed88", null ],
    [ "transparentShadowCastersMode", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a9b568558ac92b819f6c141cfae20613f", null ],
    [ "autoLights", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#acf473d568a738bb42e81ef872fe600a2", null ],
    [ "manualLightList", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#aa05f120964ef4bf3127dffa67c03480a", null ],
    [ "scissoring", "class_ogre_1_1_scene_manager_1_1_scene_mgr_queued_renderable_visitor.html#a1f81a13b0b7ff39afa5e96e35728a40e", null ]
];
